@@ -1,6 +1,9 @@
+from __future__ import absolute_import
+
 import inspect
 
-from decorators import before, after, around, patcher
+from exam.decorators import before, after, around, patcher  # NOQA
+from exam.objects import noop  # NOQA
 
 
 class MultipleGeneratorsContextManager(object):
@@ -35,10 +38,14 @@ class Exam(object):
                     yield attr, value
 
     def setUp(self):
+        getattr(super(Exam, self), 'setUp', noop)()
+
         for _, value in self.attrs_of_type(before):
             value(self)
 
     def tearDown(self):
+        getattr(super(Exam, self), 'tearDown', noop)()
+
         for _, value in self.attrs_of_type(after):
             value(self)
 
